@@ -34,7 +34,9 @@ type Config interface {
 	DefaultRepo() *string
 	MultiLevelRepo() *bool
 	SkipRender() bool
-	TransformableAllowList() []latestV1.ResourceFilter
+	TransformAllowList() []latestV1.ResourceFilter
+	TransformDenyList() []latestV1.ResourceFilter
+	TransformRulesFile() string
 }
 
 // Artifact contains all information about a completed deployment
