@@ -78,6 +78,18 @@ func GetDependencies(ctx context.Context, buildCfg BuildConfig, cfg Config) ([]s
 	return resultPair(result)
 }
 
+// GetDependencies finds the sources dependency for the given docker artifact.
+// it caches the results for the computed dependency which can be used by `GetDependenciesCached`
+// All paths are relative to the workspace.
+func GetDependenciesByDockerCopyFromTo(ctx context.Context, buildCfg BuildConfig, cfg Config) (map[string][]string, error) {
+	absDockerfilePath, err := NormalizeDockerfilePath(buildCfg.workspace, buildCfg.dockerfilePath)
+	if err != nil {
+		return nil, fmt.Errorf("normalizing dockerfilePath path: %w", err)
+	}
+	ftToDependencies := getDependenciesByDockerCopyFromTo(ctx, buildCfg.workspace, buildCfg.dockerfilePath, absDockerfilePath, buildCfg.args, cfg)
+	return resultPairForDockerCopyFromTo(ftToDependencies)
+}
+
 // GetDependenciesCached reads from cache finds the sources dependency for the given docker artifact.
 // All paths are relative to the workspace.
 func GetDependenciesCached(ctx context.Context, buildCfg BuildConfig, cfg Config) ([]string, error) {
@@ -103,6 +115,17 @@ func resultPair(deps interface{}) ([]string, error) {
 	}
 }
 
+func resultPairForDockerCopyFromTo(deps interface{}) (map[string][]string, error) {
+	switch t := deps.(type) {
+	case error:
+		return nil, t
+	case map[string][]string:
+		return t, nil
+	default:
+		return nil, fmt.Errorf("internal error when retrieving cache result of type %T", t)
+	}
+}
+
 func getDependencies(ctx context.Context, workspace string, dockerfilePath string, absDockerfilePath string, buildArgs map[string]*string, cfg Config) interface{} {
 	// If the Dockerfile doesn't exist, we can't compute the dependency.
 	// But since we know the Dockerfile is a dependency, let's return a list
@@ -112,7 +135,7 @@ func getDependencies(ctx context.Context, workspace string, dockerfilePath strin
 		return []string{dockerfilePath}
 	}
 
-	fts, err := readCopyCmdsFromDockerfile(ctx, false, absDockerfilePath, workspace, buildArgs, cfg)
+	fts, err := ReadCopyCmdsFromDockerfile(ctx, false, absDockerfilePath, workspace, buildArgs, cfg)
 	if err != nil {
 		return err
 	}
@@ -124,7 +147,7 @@ func getDependencies(ctx context.Context, workspace string, dockerfilePath strin
 
 	deps := make([]string, 0, len(fts))
 	for _, ft := range fts {
-		deps = append(deps, ft.from)
+		deps = append(deps, ft.From)
 	}
 
 	files, err := WalkWorkspace(workspace, excludes, deps)
@@ -151,6 +174,52 @@ func getDependencies(ctx context.Context, workspace string, dockerfilePath strin
 	return dependencies
 }
 
+func getDependenciesByDockerCopyFromTo(ctx context.Context, workspace string, dockerfilePath string, absDockerfilePath string, buildArgs map[string]*string, cfg Config) interface{} {
+	// If the Dockerfile doesn't exist, we can't compute the dependency.
+	// But since we know the Dockerfile is a dependency, let's return a list
+	// with only that file. It makes errors down the line more actionable
+	// than returning an error now.
+	if _, err := os.Stat(absDockerfilePath); os.IsNotExist(err) {
+		return []string{dockerfilePath}
+	}
+
+	fts, err := ReadCopyCmdsFromDockerfile(ctx, false, absDockerfilePath, workspace, buildArgs, cfg)
+	if err != nil {
+		return err
+	}
+
+	excludes, err := readDockerignore(workspace, absDockerfilePath)
+	if err != nil {
+		return fmt.Errorf("reading .dockerignore: %w", err)
+	}
+
+	ftToDependencies := map[string][]string{}
+	for _, ft := range fts {
+		files, err := WalkWorkspace(workspace, excludes, []string{ft.From})
+		if err != nil {
+			return fmt.Errorf("walking workspace: %w", err)
+		}
+
+		// Always add dockerfile even if it's .dockerignored. The daemon will need it anyways.
+		if !filepath.IsAbs(dockerfilePath) {
+			files[dockerfilePath] = true
+		} else {
+			files[absDockerfilePath] = true
+		}
+
+		// Ignore .dockerignore
+		delete(files, ".dockerignore")
+
+		var dependencies []string
+		for file := range files {
+			dependencies = append(dependencies, file)
+		}
+		sort.Strings(dependencies)
+		ftToDependencies[ft.String()] = dependencies
+	}
+	return ftToDependencies
+}
+
 // readDockerignore reads patterns to ignore
 func readDockerignore(workspace string, absDockerfilePath string) ([]string, error) {
 	var excludes []string
