@@ -114,8 +114,6 @@ func TestSyncRepo(t *testing.T) {
 			cmds: []cmdResponse{
 				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
 				{cmd: "git fetch origin master"},
-				{cmd: "git diff --name-only --ignore-submodules HEAD"},
-				{cmd: "git diff --name-only --ignore-submodules origin/master..."},
 				{cmd: "git reset --hard origin/master"},
 			},
 			syncFlag: "always",
@@ -131,6 +129,16 @@ func TestSyncRepo(t *testing.T) {
 			syncFlag:  "always",
 			shouldErr: true,
 		},
+		{
+			description: "existing repo with no remotes fails",
+			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
+			existing:    true,
+			cmds: []cmdResponse{
+				{cmd: "git remote -v"},
+			},
+			syncFlag:  "always",
+			shouldErr: true,
+		},
 		{
 			description: "existing dirty repo with sync off succeeds",
 			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master", Sync: util.BoolPtr(false)},
@@ -152,30 +160,28 @@ func TestSyncRepo(t *testing.T) {
 			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
 		},
 		{
-			description: "existing repo with uncommitted changes and sync on fails",
+			description: "existing repo with uncommitted changes and sync on resets",
 			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master", Sync: util.BoolPtr(true)},
 			existing:    true,
 			cmds: []cmdResponse{
 				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
 				{cmd: "git fetch origin master"},
-				{cmd: "git diff --name-only --ignore-submodules HEAD", out: "pkg/foo\npkg/bar"},
-			},
-			syncFlag:  "always",
-			shouldErr: true,
-		},
-		{
-			description: "existing repo with unpushed commits and sync on fails",
-			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master", Sync: util.BoolPtr(true)},
-			existing:    true,
-			cmds: []cmdResponse{
-				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
-				{cmd: "git fetch origin master"},
-				{cmd: "git diff --name-only --ignore-submodules HEAD"},
-				{cmd: "git diff --name-only --ignore-submodules origin/master...", out: "pkg/foo\npkg/bar"},
 				{cmd: "git reset --hard origin/master"},
 			},
-			syncFlag:  "always",
-			shouldErr: true,
+			syncFlag: "always",
+			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
+		},
+		{
+			description: "existing repo with unpushed commits and sync on resets",
+			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master", Sync: util.BoolPtr(true)},
+			existing:    true,
+			cmds: []cmdResponse{
+				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
+				{cmd: "git fetch origin master"},
+				{cmd: "git reset --hard origin/master"},
+			},
+			syncFlag: "always",
+			expected: "iSEL5rQfK5EJ2yLhnW8tUgcVOvDC8Wjl",
 		},
 		{
 			description: "existing repo update fails on fetch",
@@ -188,31 +194,6 @@ func TestSyncRepo(t *testing.T) {
 			syncFlag:  "always",
 			shouldErr: true,
 		},
-		{
-			description: "existing repo update fails on diff remote",
-			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
-			existing:    true,
-			cmds: []cmdResponse{
-				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
-				{cmd: "git fetch origin master"},
-				{cmd: "git diff --name-only --ignore-submodules HEAD"},
-				{cmd: "git diff --name-only --ignore-submodules origin/master...", err: errors.New("error")},
-			},
-			syncFlag:  "always",
-			shouldErr: true,
-		},
-		{
-			description: "existing repo update fails on diff working dir",
-			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
-			existing:    true,
-			cmds: []cmdResponse{
-				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
-				{cmd: "git fetch origin master"},
-				{cmd: "git diff --name-only --ignore-submodules HEAD", err: errors.New("error")},
-			},
-			syncFlag:  "always",
-			shouldErr: true,
-		},
 		{
 			description: "existing repo update fails on reset",
 			g:           latestV1.GitInfo{Repo: "http://github.com/foo.git", Path: "bar/skaffold.yaml", Ref: "master"},
@@ -220,8 +201,6 @@ func TestSyncRepo(t *testing.T) {
 			cmds: []cmdResponse{
 				{cmd: "git remote -v", out: "origin git@github.com/foo.git"},
 				{cmd: "git fetch origin master"},
-				{cmd: "git diff --name-only --ignore-submodules HEAD"},
-				{cmd: "git diff --name-only --ignore-submodules origin/master..."},
 				{cmd: "git reset --hard origin/master", err: errors.New("error")},
 			},
 			syncFlag:  "always",
