@@ -31,21 +31,18 @@ type Options struct {
 	OutFormat string
 	// Modules is the module filter for specific commands
 	Modules []string
+	// Profiles is the slice of profile names to activate.
+	Profiles []string
+	// Profile is a target profile to create or edit
+	Profile string
+	// PropagateProfiles specifies if profiles specified by the '--profile' flag should be searched across config dependencies. Otherwise only profiles defined directly in the target 'skaffold.yaml' file are activated.
+	PropagateProfiles bool
 	// Strict specifies the error-tolerance for specific commands
 	Strict bool
 
 	ModulesOptions
 	ProfilesOptions
 	BuildEnvOptions
-	TestsOptions
-}
-
-// TestsOptions holds flag values for various `skaffold inspect tests` commands
-type TestsOptions struct {
-	// Profiles is the slice of profile names to activate.
-	TestsProfiles []string
-	// Profile is a target profile to create or edit
-	TestsProfile string
 }
 
 // ModulesOptions holds flag values for various `skaffold inspect modules` commands
@@ -62,10 +59,6 @@ type ProfilesOptions struct {
 
 // BuildEnvOptions holds flag values for various `skaffold inspect build-env` commands
 type BuildEnvOptions struct {
-	// Profiles is the slice of profile names to activate.
-	Profiles []string
-	// Profile is a target profile to create or edit
-	Profile string
 	// Push specifies if images should be pushed to a registry.
 	Push *bool
 	// TryImportMissing specifies whether to attempt to import artifacts from Docker (either a local or remote registry) if not in the cache
