@@ -21,6 +21,8 @@ import (
 	"regexp"
 	"testing"
 
+	"k8s.io/apimachinery/pkg/runtime/schema"
+
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
@@ -30,7 +32,7 @@ type mockVisitor struct {
 	replaceWith interface{}
 }
 
-func (m *mockVisitor) Visit(navpath string, o map[string]interface{}, k string, v interface{}) bool {
+func (m *mockVisitor) Visit(gk schema.GroupKind, navpath string, o map[string]interface{}, k string, v interface{}, rs ResourceSelector) bool {
 	s := fmt.Sprintf("%+v", v)
 	if len(s) > 4 {
 		s = s[:4] + "..."
@@ -249,7 +251,7 @@ spec:
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			visitor := &mockVisitor{map[string]int{}, test.pivotKey, test.replaceWith}
-			actual, err := test.manifests.Visit(visitor)
+			actual, err := test.manifests.Visit(visitor, NewResourceSelectorImages(TransformAllowlist, TransformDenylist))
 			expectedVisits := map[string]int{}
 			for _, visit := range test.expected {
 				expectedVisits[visit]++
@@ -369,7 +371,7 @@ func TestShouldTransformManifest(t *testing.T) {
 	}
 	for _, test := range tests {
 		testutil.Run(t, fmt.Sprintf("%v", test.manifest), func(t *testutil.T) {
-			result := shouldTransformManifest(test.manifest)
+			result := shouldTransformManifest(test.manifest, NewResourceSelectorImages(TransformAllowlist, TransformDenylist))
 			t.CheckDeepEqual(test.expected, result)
 		})
 	}
