@@ -20,10 +20,10 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/sirupsen/logrus"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	kubernetesclient "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/client"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 )
 
 // TopLevelOwnerKey returns a key associated with the top level
@@ -38,7 +38,7 @@ func TopLevelOwnerKey(ctx context.Context, obj metav1.Object, kubeContext string
 		kind = or[0].Kind
 		obj, err = ownerMetaObject(ctx, obj.GetNamespace(), kubeContext, or[0])
 		if err != nil {
-			logrus.Warnf("unable to get owner from reference: %v", or[0])
+			log.Entry(ctx).Warnf("unable to get owner from reference: %v", or[0])
 			return ""
 		}
 	}
