@@ -234,93 +234,78 @@ func TestGetDeployStatus(t *testing.T) {
 	tests := []struct {
 		description  string
 		counter      *counter
-		deployments  []*resource.Resource
+		sc           proto.StatusCode
 		expected     string
 		expectedCode proto.StatusCode
 		shouldErr    bool
 	}{
 		{
-			description: "one error",
-			counter:     &counter{total: 2, failed: 1},
-			deployments: []*resource.Resource{
-				resource.NewResource("foo", resource.ResourceTypes.Deployment, "test", time.Second).
-					WithPodStatuses([]proto.StatusCode{proto.StatusCode_STATUSCHECK_NODE_DISK_PRESSURE}),
-			},
+			description:  "one error",
+			counter:      &counter{total: 2, failed: 1},
 			expected:     "1/2 deployment(s) failed",
-			expectedCode: proto.StatusCode_STATUSCHECK_NODE_DISK_PRESSURE,
+			sc:           proto.StatusCode_STATUSCHECK_POD_INITIALIZING,
+			expectedCode: proto.StatusCode_STATUSCHECK_POD_INITIALIZING,
 			shouldErr:    true,
 		},
 		{
-			description: "no error",
-			counter:     &counter{total: 2},
-			deployments: []*resource.Resource{
-				withStatus(
-					resource.NewResource("r1", resource.ResourceTypes.Deployment, "test", 1),
-					&proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_SUCCESS},
-				),
-				withStatus(
-					resource.NewResource("r2", resource.ResourceTypes.Deployment, "test", 1),
-					&proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_SUCCESS},
-				),
-			},
+			description:  "no error",
+			sc:           proto.StatusCode_STATUSCHECK_SUCCESS,
+			expectedCode: proto.StatusCode_STATUSCHECK_SUCCESS,
+			counter:      &counter{total: 2},
 		},
 		{
-			description: "multiple errors",
-			counter:     &counter{total: 3, failed: 2},
-			expected:    "2/3 deployment(s) failed",
-			deployments: []*resource.Resource{
-				resource.NewResource("foo", resource.ResourceTypes.Deployment, "test", time.Second).
-					WithPodStatuses([]proto.StatusCode{proto.StatusCode_STATUSCHECK_NODE_DISK_PRESSURE}),
-			},
-			expectedCode: proto.StatusCode_STATUSCHECK_NODE_DISK_PRESSURE,
+			description:  "multiple errors",
+			counter:      &counter{total: 3, failed: 2},
+			expected:     "2/3 deployment(s) failed",
+			sc:           proto.StatusCode_STATUSCHECK_CONFIG_CONNECTOR_FAILED,
+			expectedCode: proto.StatusCode_STATUSCHECK_CONFIG_CONNECTOR_FAILED,
 			shouldErr:    true,
 		},
 		{
-			description: "0 deployments",
-			counter:     &counter{},
+			description:  "0 deployments",
+			counter:      &counter{total: 0},
+			expectedCode: proto.StatusCode_STATUSCHECK_SUCCESS,
 		},
 		{
-			description: "unable to retrieve pods for deployment",
-			counter:     &counter{total: 1, failed: 1},
-			deployments: []*resource.Resource{
-				withStatus(
-					resource.NewResource("deployment", resource.ResourceTypes.Deployment, "test", 1),
-					&proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_FETCH_ERR},
-				),
-			},
-			shouldErr:    true,
+			description:  "unable to retrieve pods for deployment",
+			counter:      &counter{total: 1, failed: 1},
+			sc:           proto.StatusCode_STATUSCHECK_DEPLOYMENT_FETCH_ERR,
 			expectedCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_FETCH_ERR,
+			shouldErr:    true,
 		},
 		{
-			description: "one deployment failed and others cancelled and or succeeded",
-			counter:     &counter{total: 3, failed: 2},
-			deployments: []*resource.Resource{
-				withStatus(
-					resource.NewResource("deployment-cancelled", resource.ResourceTypes.Deployment, "test", 1),
-					&proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_USER_CANCELLED},
-				),
-				withStatus(
-					resource.NewResource("deployment-success", resource.ResourceTypes.Deployment, "test", 1),
-					&proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_SUCCESS},
-				),
-				withStatus(
-					resource.NewResource("deployment", resource.ResourceTypes.Deployment, "test", 1),
-					&proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_FETCH_ERR},
-				),
-			},
+			description:  "one deployment failed and others cancelled and or succeeded",
+			counter:      &counter{total: 3, failed: 2},
+			sc:           proto.StatusCode_STATUSCHECK_NODE_DISK_PRESSURE,
+			expectedCode: proto.StatusCode_STATUSCHECK_NODE_DISK_PRESSURE,
+			expected:     "2/3 deployment(s) failed",
+			shouldErr:    true,
+		},
+		{
+			description:  "deployments did not stabilize within deadline returns the pod error",
+			counter:      &counter{total: 1, failed: 1},
+			sc:           proto.StatusCode_STATUSCHECK_UNHEALTHY,
+			expected:     "1/1 deployment(s) failed",
+			expectedCode: proto.StatusCode_STATUSCHECK_UNHEALTHY,
+			shouldErr:    true,
+		},
+		{
+			description:  "user cancelled session",
+			counter:      &counter{total: 2, failed: 0, cancelled: 2},
+			sc:           proto.StatusCode_STATUSCHECK_USER_CANCELLED,
+			expected:     "2/2 deployment(s) status check cancelled",
+			expectedCode: proto.StatusCode_STATUSCHECK_USER_CANCELLED,
 			shouldErr:    true,
-			expectedCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_FETCH_ERR,
 		},
 	}
 
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			testEvent.InitializeState([]latestV1.Pipeline{{}})
-			errCode, err := getSkaffoldDeployStatus(test.counter, test.deployments)
+			actual, err := getSkaffoldDeployStatus(context.Background(), test.counter, test.sc)
 			t.CheckError(test.shouldErr, err)
+			t.CheckDeepEqual(test.expectedCode, actual)
 			if test.shouldErr {
 				t.CheckErrorContains(test.expected, err)
-				t.CheckDeepEqual(test.expectedCode, errCode)
 			}
 		})
 	}
@@ -388,7 +373,7 @@ func TestPrintSummaryStatus(t *testing.T) {
 
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			monitor := Monitor{labeller: labeller}
+			monitor := monitor{labeller: labeller}
 			out := new(bytes.Buffer)
 			rc := newCounter(10)
 			rc.pending = test.pending
@@ -483,7 +468,7 @@ func TestPrintStatus(t *testing.T) {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			out := new(bytes.Buffer)
 			testEvent.InitializeState([]latestV1.Pipeline{{}})
-			monitor := Monitor{labeller: labeller}
+			monitor := monitor{labeller: labeller}
 			actual := monitor.printStatus(test.rs, out)
 			t.CheckDeepEqual(test.expectedOut, out.String())
 			t.CheckDeepEqual(test.expected, actual)
@@ -529,29 +514,43 @@ func TestResourceMarkProcessed(t *testing.T) {
 	tests := []struct {
 		description string
 		c           *counter
-		err         error
 		expected    counter
+		ctxErr      error
+		sc          proto.StatusCode
+		expectedB   bool
 	}{
 		{
 			description: "when deployment failed, counter is updated",
 			c:           newCounter(10),
-			err:         errors.New("some ae"),
+			sc:          proto.StatusCode_STATUSCHECK_DEADLINE_EXCEEDED,
 			expected:    counter{total: 10, failed: 1, pending: 9},
+			expectedB:   true,
+		},
+		{
+			description: "when deployment is cancelled, failed is not updated",
+			c:           newCounter(10),
+			ctxErr:      context.Canceled,
+			expected:    counter{total: 10, failed: 0, pending: 9, cancelled: 1},
 		},
 		{
 			description: "when deployment is successful, counter is updated",
 			c:           newCounter(10),
+			sc:          proto.StatusCode_STATUSCHECK_SUCCESS,
 			expected:    counter{total: 10, failed: 0, pending: 9},
 		},
 		{
 			description: "counter when 1 deployment is updated correctly",
 			c:           newCounter(1),
+			sc:          proto.StatusCode_STATUSCHECK_SUCCESS,
 			expected:    counter{total: 1, failed: 0, pending: 0},
 		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			t.CheckDeepEqual(test.expected, test.c.markProcessed(test.err), cmp.AllowUnexported(counter{}))
+			ctx := testCtx{err: test.ctxErr, Context: context.Background()}
+			actual, actualB := test.c.markProcessed(ctx, test.sc)
+			t.CheckDeepEqual(test.expected, actual, cmp.AllowUnexported(counter{}))
+			t.CheckDeepEqual(test.expectedB, actualB, cmp.AllowUnexported(counter{}))
 		})
 	}
 }
@@ -642,3 +641,12 @@ type statusConfig struct {
 }
 
 func (c *statusConfig) GetKubeContext() string { return TestKubeContext }
+
+type testCtx struct {
+	context.Context
+	err error
+}
+
+func (t testCtx) Err() error {
+	return t.err
+}
