@@ -41,10 +41,10 @@ type withNotification struct {
 	deploy.Deployer
 }
 
-func (w withNotification) Deploy(ctx context.Context, out io.Writer, builds []graph.Artifact) ([]string, error) {
-	ns, err := w.Deployer.Deploy(ctx, out, builds)
+func (w withNotification) Deploy(ctx context.Context, out io.Writer, builds []graph.Artifact) error {
+	err := w.Deployer.Deploy(ctx, out, builds)
 	if err != nil {
 		fmt.Fprint(out, terminalBell)
 	}
-	return ns, err
+	return err
 }
