@@ -21,6 +21,7 @@ import (
 	"io"
 
 	pkgkubectl "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubectl"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/logger"
 	v1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 )
 
@@ -40,12 +41,14 @@ type Syncer interface {
 type PodSyncer struct {
 	kubectl    *pkgkubectl.CLI
 	namespaces *[]string
+	formatter  logger.Formatter
 }
 
-func NewPodSyncer(cli *pkgkubectl.CLI, namespaces *[]string) *PodSyncer {
+func NewPodSyncer(cli *pkgkubectl.CLI, namespaces *[]string, formatter logger.Formatter) *PodSyncer {
 	return &PodSyncer{
 		kubectl:    cli,
 		namespaces: namespaces,
+		formatter:  formatter,
 	}
 }
 
